;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "calfw" "20251018.1232"
  "Calendar view framework."
  '((emacs "28.1"))
  :url "https://github.com/haji-ali/emacs-calfw"
  :commit "c6f2fcdccfbc4b944f341ec873c0b148eee0a0fe"
  :revdesc "c6f2fcdccfbc"
  :keywords '("calendar")
  :authors '(("SAKURAI Masashi" . "m.sakuraiatkiwanami.net"))
  :maintainers '(("Al Haji-Ali" . "abdo.haji.aliatgmail.com")))
